Error

Enum Error 

pub enum Error {
    Generic(u32),
    Mem,
    AbiMismatch,
    Incapable,
    UnsupportedBitstream,
    UnsupportedFrame,
    CorruptFrame,
    InvalidParam,
    ListEnd,
}

Variants



Generic(u32)



Mem



AbiMismatch



Incapable



UnsupportedBitstream

The bitstream was unable to be parsed at the highest level. The decoder is unable to proceed. This error SHOULD be treated as fatal to the stream.



UnsupportedFrame

The decoder does not implement a feature required by the encoder. This return code should only be used for features that prevent future pictures from being properly decoded. This error MAY be treated as fatal to the stream or MAY be treated as fatal to the current GOP.



CorruptFrame

There was a problem decoding the current frame. This return code should only be used for failures that prevent future pictures from being properly decoded. This error MAY be treated as fatal to the stream or MAY be treated as fatal to the current GOP. If decoding is continued for the current GOP, artifacts may be present.



InvalidParam



ListEnd